@@ -14,10 +14,10 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
+from typing import Any, Dict, Union
 from langtrace_python_sdk.constants import LANGTRACE_SDK_NAME
 from langtrace_python_sdk.utils import set_span_attribute
-from openai import NOT_GIVEN
-from tiktoken import get_encoding
+from langtrace_python_sdk.types import NOT_GIVEN
 from tiktoken import get_encoding, list_encoding_names
 
 from langtrace_python_sdk.constants.instrumentation.common import (
@@ -25,7 +25,7 @@ from langtrace_python_sdk.constants.instrumentation.common import (
     TIKTOKEN_MODEL_MAPPING,
 )
 from langtrace_python_sdk.constants.instrumentation.openai import OPENAI_COST_TABLE
-from langtrace.trace_attributes import SpanAttributes, Event
+from langtrace.trace_attributes import SpanAttributes
 from importlib_metadata import version as v
 import json
 from opentelemetry import baggage
@@ -123,9 +123,12 @@ def get_llm_request_attributes(kwargs, prompts=None, model=None, operation_name=
 
     top_p = kwargs.get("p", None) or kwargs.get("top_p", None)
     tools = kwargs.get("tools", None)
+    tool_choice = kwargs.get("tool_choice", None)
     return {
         SpanAttributes.LLM_OPERATION_NAME: operation_name,
-        SpanAttributes.LLM_REQUEST_MODEL: model or kwargs.get("model"),
+        SpanAttributes.LLM_REQUEST_MODEL: model
+        or kwargs.get("model")
+        or "gpt-3.5-turbo",
         SpanAttributes.LLM_IS_STREAMING: kwargs.get("stream"),
         SpanAttributes.LLM_REQUEST_TEMPERATURE: kwargs.get("temperature"),
         SpanAttributes.LLM_TOP_K: top_k,
@@ -138,14 +141,16 @@ def get_llm_request_attributes(kwargs, prompts=None, model=None, operation_name=
         SpanAttributes.LLM_FREQUENCY_PENALTY: kwargs.get("frequency_penalty"),
         SpanAttributes.LLM_REQUEST_SEED: kwargs.get("seed"),
         SpanAttributes.LLM_TOOLS: json.dumps(tools) if tools else None,
-        SpanAttributes.LLM_TOOL_CHOICE: kwargs.get("tool_choice"),
+        SpanAttributes.LLM_TOOL_CHOICE: (
+            json.dumps(tool_choice) if tool_choice else None
+        ),
         SpanAttributes.LLM_REQUEST_LOGPROPS: kwargs.get("logprobs"),
         SpanAttributes.LLM_REQUEST_LOGITBIAS: kwargs.get("logit_bias"),
         SpanAttributes.LLM_REQUEST_TOP_LOGPROPS: kwargs.get("top_logprobs"),
     }
 
 
-def get_extra_attributes():
+def get_extra_attributes() -> Union[Dict[str, Any], object]:
     extra_attributes = baggage.get_baggage(LANGTRACE_ADDITIONAL_SPAN_ATTRIBUTES_KEY)
     return extra_attributes or {}
 
@@ -228,8 +233,16 @@ def set_event_completion(span: Span, result_content):
     )
 
 
-def set_span_attributes(span: Span, attributes: dict):
-    for field, value in attributes.model_dump(by_alias=True).items():
+def set_span_attributes(span: Span, attributes: Any) -> None:
+    from pydantic import BaseModel
+
+    attrs = (
+        attributes.model_dump(by_alias=True)
+        if isinstance(attributes, BaseModel)
+        else attributes
+    )
+
+    for field, value in attrs.items():
         set_span_attribute(span, field, value)
 
 
@@ -255,11 +268,13 @@ class StreamWrapper:
             self._span_started = True
 
     def cleanup(self):
-        if self.completion_tokens==0:
-            response_model = 'cl100k_base'
+        if self.completion_tokens == 0:
+            response_model = "cl100k_base"
             if self._response_model in list_encoding_names():
                 response_model = self._response_model
-            self.completion_tokens = estimate_tokens_using_tiktoken("".join(self.result_content), response_model)
+            self.completion_tokens = estimate_tokens_using_tiktoken(
+                "".join(self.result_content), response_model
+            )
         if self._span_started:
             set_span_attribute(
                 self.span,
@@ -420,8 +435,10 @@ class StreamWrapper:
     def process_chunk(self, chunk):
         # Mistral nests the chunk data under a `data` attribute
         if (
-            hasattr(chunk, "data") and chunk.data is not None
-            and hasattr(chunk.data, "choices") and chunk.data.choices is not None
+            hasattr(chunk, "data")
+            and chunk.data is not None
+            and hasattr(chunk.data, "choices")
+            and chunk.data.choices is not None
         ):
             chunk = chunk.data
         self.set_response_model(chunk=chunk)
